package CF2022::Controller::Products;
use Mojo::Base 'Mojolicious::Controller';
use Mojo::UserAgent;

sub list {
    my $c = shift->openapi->valid_input or return;

    my $ua = Mojo::UserAgent->new;

    my $products = $ua->get( sprintf ('%s/organizers/%s/events/%s/items/',
        $c->config->{pretix_api},
        $c->config->{pretix_organizer},
        $c->config->{pretix_event},
    ), {
        Authorization => 'Token ' . $c->config->{pretix_token}
    } )->result->json;

    my $quotas = $ua->get( sprintf ('%s/organizers/%s/events/%s/quotas/',
        $c->config->{pretix_api},
        $c->config->{pretix_organizer},
        $c->config->{pretix_event},
    ), {
        Authorization => 'Token ' . $c->config->{pretix_token}
    } )->result->json;

    my $q = {};

    QUOTE:
    foreach my $record ( @{ $quotas->{results} } ) {
        next if ! $record->{size};

        my $quota = $ua->get( sprintf ('%s/organizers/%s/events/%s/quotas/%d/availability/',
            $c->config->{pretix_api},
            $c->config->{pretix_organizer},
            $c->config->{pretix_event},
            $record->{id},
        ), {
            Authorization => 'Token ' . $c->config->{pretix_token}
        } )->result->json;

        ITEM:
        foreach my $item_id ( @{ $record->{items} } ) {
            $q->{$item_id}{total} += $quota->{total_size};
            $q->{$item_id}{available} += $quota->{available_number};
            foreach my $variation_id ( @{ $record->{variations} } ) {
                $q->{$item_id}{$variation_id}{total} += $quota->{total_size};
                $q->{$item_id}{$variation_id}{available} += $quota->{available_number};
            }
        }
    }

$c->trace($q);

    my @options = ();

    RECORD:
    foreach my $record ( @{ $products->{results} } ) {
        next RECORD if ! $record->{active};

        push @options, {
            id          => $record->{id},
            name        => $record->{name}{en},
            price       => $record->{default_price} + 0,
            free_price  => $record->{free_price},
            category_id => $record->{category},
            quotes      => $q->{$record->{id}},
            variations  => [
                map {{
                    id     => $_->{id},
                    value  => $_->{value}{en},
                    price  => $_->{price} + 0,
                    quotes => $q->{$record->{id}}{$_->{id} },
                }} @{ $record->{variations} }
            ],
        };
    }

    $c->render(openapi => \@options);
}

1;
